import React, { useState, useEffect } from 'react'
import Taro, { Current } from '@tarojs/taro'
import { RichText, Input } from '@tarojs/components'
import request, { apis } from '@/utils/request'
import { useModel } from '@/store'
import Page from '@/layouts'
import toolclass from '@/utils/toolclass.js'
import { getShareObject } from '@/utils/share.js'
import GetUserPhone from '@/components/GetUserPhone/index'
import '@/assets/css/reset.less'
import '@/assets/css/iconfont.less'
import './index.less'

export default function HuoDongDetail () {

  const { user } = useModel('user')
  const [DataLock, setDataLock] = useState(false)
  const [HasJoin, setHasJoin] = useState(null)
  const [HasSign, setHasSign] = useState(null)
  const [CanJoin, setCanJoin] = useState(null)
  const [JoinBtnText, setJoinBtnText] = useState(null)
  const [JoinBtnStatus, setJoinBtnStatus] = useState(false)
  const [ShowJoinNumPopup, setShowJoinNumPopup] = useState(false)
  const [JoinNum, setJoinNum] = useState(null)
  const [ShowGetUserPhoneLayer, setShowGetUserPhoneLayer] = useState(false)
  const [CurrnetHuoDongId] = useState(Current.router.params.id) // 当前活动id
  const [ActivityDetail, setActivityDetail] = useState(null) // 活动详情

  Taro.useShareAppMessage(() => {
    return getShareObject({
      title: ActivityDetail.title,
      id: CurrnetHuoDongId,
      image: ActivityDetail.imgUrl
    }, user)
  })

  useEffect(() => {
    GetActivityDetail()
  }, [CurrnetHuoDongId])

  useEffect(() => {
    if (ActivityDetail !== null) {
      ToSetJoinBtnText()
    }
  }, [HasJoin, CanJoin, HasSign, ActivityDetail])

  const GetActivityDetail = () => { // 获取活动详情
    request({ ...apis.getActivityDetail, args: { id: CurrnetHuoDongId } }).then((res) => {
      setActivityDetail(res)
      CheckActivityJoin()
    })
  }

  const CheckActivityJoin = () => { // 查询活动参加详情
    request({ ...apis.checkActivityJoin, args: { id: CurrnetHuoDongId } }).then((res) => {
      setHasJoin(!!res.dynamic.isSign)
      setCanJoin(!!res.dynamic.isEnlist)
      setHasSign(!!res.enlist.isCheckin)
    })
  }

  const ToSetJoinBtnText = () => {
    if (ActivityDetail.activityStatus - 0 === 2) {
      setJoinBtnText(`已结束`)
      return false
    } else {
      if (HasSign) {
        setJoinBtnText(`已签到`)
        return false
      } else {
        if (HasJoin) {
          if (ActivityDetail.activityStatus - 0 === 1) {
            setJoinBtnText(`已报名`)
          } else if (ActivityDetail.activityStatus - 0 === 0) {
            setJoinBtnStatus(true)
            setJoinBtnText(`去签到`)
          }
          return false
        } else {
          if (CanJoin) {
            setJoinBtnStatus(true)
            setJoinBtnText(`去报名`)
            return false
          } else {
            setJoinBtnText(null)
            return false
          }
        }
      }
    }
  }

  const ConfirmToJoin = () => {
    if (JoinNum === null || JoinNum - 0 < 1) {
      Taro.showToast({ title: '请填入参加活动人数', icon: 'none' })
      setDataLock(false)
    } else {
      let Data = {
        phone,
        personId,
        dynamicId,
        name: nickname,
        orgId,
        attendNum: JoinNum - 0 || 1,
        sharePerson: null,
        sharePersonName: null,
        sharePersonType: null
      }
      request({ ...apis.JoinActivity, data: { ...Data } }).then(() => {
        setHasJoin(true)
        setShowJoinNumPopup(false)
        setDataLock(false)
      }).catch((res) => {
        Taro.showToast({ title: res, icon: 'none' })
        setDataLock(false)
      })
    }
  }

  const ToJoin = () => { // 去报名
    if (DataLock || ActivityDetail === null || !JoinBtnStatus) return
    setDataLock(true)
    if (JoinBtnText === '去签到') {
      Taro.navigateTo({ url: `/pages/HuoDong/HuoDongSign/index?id=${ActivityDetail.dynamicId}` })
    } else {
      const { personId, phone, nickname, orgId } = user
      const { dynamicId } = ActivityDetail
      if (!phone) { // 未授权手机号，唤起授权手机号弹窗
        setShowGetUserPhoneLayer(true)
        setDataLock(false)
        return false
      }
      setShowJoinNumPopup(true)
    }
  }

  const JoinNumChange = (e) => {
    setJoinNum(e.detail.value)
  }

  const showError = err => {
    Taro.showModal({
      title: '错误',
      content: err,
      showCancel: false
    })
  }

  return (
    <Page>
      <view className='HuoDongDetail'>

        <GetUserPhone visible={ShowGetUserPhoneLayer} onError={err => showError(`授权手机失败: ${err}`)} onCancel={() => { }}></GetUserPhone>

        <view className='BannerLayer'></view>
        {
          ActivityDetail !== null &&
          <view className='Banner'>
            <image mode='aspectFill' src={ActivityDetail.imgUrl} className='centerLabel'></image>
          </view>
        }
        {
          ActivityDetail !== null &&
          <view className='Info'>
            <view className='MainInfo'>
              <text className='Name'>{ActivityDetail.title}</text>
              <text className='Tips'>{ActivityDetail.enlisted}人已报名</text>
              <view className='flex-h'>
                <text>活动时间：</text>
                <view className='flex-item'>{toolclass.FormatDate(ActivityDetail.startDate)}<text>限{ActivityDetail.enlistNum}人</text></view>
              </view>
              <view className='flex-h'>
                <text>活动地址：</text>
                <view className='flex-item'>{ActivityDetail.address}</view>
              </view>
              <view className='flex-h'>
                <text>报名截止：</text>
                <view className='flex-item'>{toolclass.FormatDate(ActivityDetail.enlistEnd)}</view>
              </view>
            </view>

            <view className='Desc'>
              <text>活动介绍</text>
              <RichText nodes={`${ActivityDetail.desc.replace(/font-size\:\s(\d+)px/ig, 'font-size: $1rpx')}`}></RichText>
            </view>

            {
              HasJoin !== null &&
              <text className={JoinBtnStatus ? 'active BottomBtn' : 'BottomBtn'} onClick={ToJoin}>{JoinBtnText}</text>
            }

          </view>
        }
        <view className={ShowJoinNumPopup ? 'JoinNumLayer active' : 'JoinNumLayer'}>
          <view className='centerLabel'>
            <text>温馨提示</text>
            <view className='flex-h Form'>
              <view>
                <text>参数人数：</text>
              </view>
              <view className='flex-item'>
                <Input placeholder='请输入活动参加人数' onInput={JoinNumChange} value={JoinNum}></Input>
              </view>
            </view>
            <view className='flex-h Bottom'>
              <view className='flex-item'>
                <text onClick={() => { setShowJoinNumPopup(false) }}>取消</text>
              </view>
              <view className='flex-item'>
                <text onClick={ConfirmToJoin}>确定</text>
              </view>
            </view>
          </view>
        </view>
      </view>
    </Page>
  )
}
